@@ -109,6 +109,7 @@ class ClientProcessInterruptHandler(object):
 
         self.client = client
 
+
     @inlineCallbacks
     def interrupt(self, last=None):
         if self.client.current_client:
@@ -248,6 +249,9 @@ class ApiRpcClient(object):
                 if 'public_urls' in app and app['public_urls']:
                     for target in app['public_urls']:
                         url_ = target['url'] + '/'
+                        if target['port']:
+                            url_ += ' -> :' + target['port']
+
                         if not url_.startswith('http://'):
                             url_ = 'http://' + url_
 
@@ -310,10 +314,11 @@ class ApiRpcClient(object):
                 if 'public_urls' in app and app['public_urls']:
                     for target in app['public_urls']:
                         url_ = target['url'] + '/'
+
                         if not url_.startswith('http://'):
                             url_ = 'http://' + url_
                         if 'service' in target and target['service']:
-                            web += '\n' + '%s -> [%s]' % (url_, target['service'])
+                            web += '\n' + '%s -> [%s:%s]' % (url_, target['service'], target['port'] or '')
                         else:
                             if web_service_:
                                 web += '\n' + '%s -> [%s]' % (url_, web_service_)
@@ -337,10 +342,14 @@ class ApiRpcClient(object):
             domain = 'https://%s' % domain
         return domain
 
-    def parse_app_ref(self, ref, args, require_service=False, app_only=False, require_app=True):
+    ip_regex = r'(([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5])\.){3}([0-9]|[1-9][0-9]|1[0-9]{2}|2[0-4][0-9]|25[0-5])'
+    host_regex = r'(([a-zA-Z0-9]|[a-zA-Z0-9][a-zA-Z0-9\-]*[a-zA-Z0-9])\.)*([A-Za-z0-9]|[A-Za-z0-9][A-Za-z0-9\-]*[A-Za-z0-9])'
+
+    def parse_app_ref(self, ref, args, require_service=False, app_only=False, require_app=True, require_host=False):
 
         app = None
         service = None
+        host = None
 
         if 'app' in args:
             app = args['app']
@@ -349,13 +358,21 @@ class ApiRpcClient(object):
             ref = ref.strip()
 
             if ref != '':
-                match = re.match('^((%s)\.)?(%s)?$' % (Application.SERVICE_REGEXP, Application.APP_REGEXP), ref)
+                match = re.match('^((%s)\.)?(%s)?(@(%s|%s))?$' % (
+                    Application.SERVICE_REGEXP,
+                    Application.APP_REGEXP,
+                    self.ip_regex,
+                    self.host_regex
+                ), ref)
                 if match:
                     if match.group(2):
                         service = match.group(2)
 
                     if match.group(3):
                         app = match.group(3)
+
+                    if match.group(5):
+                        host = match.group(5)
                 else:
                     raise ValueError('Can not parse application/service name')
 
@@ -370,7 +387,13 @@ class ApiRpcClient(object):
         if not service and require_service:
             raise ValueError('Command requires to specify a service name')
 
-        return app, service
+        if not host:
+            host = self.host
+
+        if require_host:
+            return host, app, service
+        else:
+            return app, service
 
 
     @inlineCallbacks
@@ -675,10 +698,11 @@ class ApiRpcClient(object):
     @cli('Publish an application', arguments=(
         arg('ref', help='Application name', default=None, nargs='?'),
         arg('domain', help='Domain to publish'),
+        arg('--port', help='Custom target port'),
         arg('--ssl', default=False, action='store_true', help='Ssl protocol'),
     ))
     @inlineCallbacks
-    def publish(self, domain, ref, ssl=False, **kwargs):
+    def publish(self, domain, ref, ssl=False, port=None, **kwargs):
         app_name, service = self.parse_app_ref(ref, kwargs, require_app=True)
 
         app = yield self.get_app(app_name)
@@ -686,7 +710,7 @@ class ApiRpcClient(object):
         if not app:
             print 'App not found. Can\'t publish'
         else:
-            yield self._remote_exec('publish', self.format_domain(domain, ssl), app_name, service)
+            yield self._remote_exec('publish', self.format_domain(domain, ssl), app_name, service, port)
 
     @cli('Unpublish an application', arguments=(
         arg('domain', help='Domain to unpublish'),
@@ -707,11 +731,13 @@ class ApiRpcClient(object):
         arg('--no-tty', default=False, action='store_true', help='Disable tty binding'),
     ))
     def run(self, ref, command, no_tty=False, **kwargs):
-        app, service = self.parse_app_ref(ref, kwargs, require_service=True)
-        if no_tty:
-            return self._remote_exec('run', self.format_app_srv(app, service), command)
-        else:
-            return self._exec_remote_with_pty('run', self.format_app_srv(app, service), command)
+        host, app, service = self.parse_app_ref(ref, kwargs, require_service=True, require_host=True)
+
+        with self.override_host(host):
+            if no_tty:
+                return self._remote_exec('run', self.format_app_srv(app, service), command)
+            else:
+                return self._exec_remote_with_pty('run', self.format_app_srv(app, service), command)
 
     ############################################################
 
